==> mx-welcome_25.06.01mx25.tar.xz: mx-welcome/translations/mx-welcome_fr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="fr">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="mainwindow.ui" line="14"/>
        <location filename="mainwindow.cpp" line="65"/>
        <location filename="mainwindow.cpp" line="255"/>
        <location filename="mainwindow.cpp" line="264"/>
        <source>MX Welcome</source>
        <translation>MX Centre d’accueil - MX Welcome</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="80"/>
        <source>Quit application</source>
        <translation>Quitter l’application</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="83"/>
        <source>Close</source>
        <translation>Quitter</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="90"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="112"/>
        <source>About this application</source>
        <translation>À propos de cette application</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="115"/>
        <source>About...</source>
        <translation>À propos...</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="122"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="203"/>
        <source>Welcome</source>
        <translation>Centre d’accueil - Welcome</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="484"/>
        <source>Install MX Linux</source>
        <translation>Installer MX Linux</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="510"/>
        <source>Tweak (Panel, etc...)</source>
        <translation>Ajustements (Tableau de bord, etc. ...)</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="536"/>
        <source>Tools</source>
        <translation>Outils </translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="568"/>
        <source>Wiki</source>
        <translation>Wiki</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="600"/>
        <source>Users Manual</source>
        <translation>Manuel de l’utilisateur</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="626"/>
        <source>FAQ</source>
        <translation>FAQ</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="652"/>
        <source>Tour</source>
        <translation>Tour</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="674"/>
        <source>Popular Apps</source>
        <translation>Applications populaires</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="700"/>
        <source>Contribute</source>
        <translation>Contribuer</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="732"/>
        <source>Videos</source>
        <translation>Vidéos</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="764"/>
        <source>Forums</source>
        <translation>Forums</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="790"/>
        <source>About</source>
        <translation>À propos</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="798"/>
        <source>SHORT SYSTEM REPORT:</source>
        <translation>RAPPORT SUCCINCT DU SYSTÈME :</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="805"/>
        <source>DESKTOP</source>
        <translation>BUREAU</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="819"/>
        <source>Quick-System-Info Full Report</source>
        <translation>Quick-System-Info rapport complet</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="829"/>
        <source>Terms of Use</source>
        <translation>Conditions d’utilisation</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="846"/>
        <source>The name “MX Linux” is covered by Linux Foundation Sublicense No. 20140605-0483. We develop software that is covered by a free license that can be examined in the Wiki list. We also include software developed by others that is under a free license.</source>
        <translation>Le nom « MX Linux » est couvert par la sous-licence de la Fondation Linux n° 20140605-0483. Nous développons des logiciels qui sont couverts par une licence libre qui peut être examinée dans la liste Wiki. Nous incluons également des logiciels développés par d’autres qui sont sous une licence libre.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="856"/>
        <source>MX VERSION</source>
        <translation>VERSION MX</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="863"/>
        <source>DEBIAN VERSION:</source>
        <translation>VERSION DEBIAN :</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="870"/>
        <source>SUPPORTED UNTIL:</source>
        <translation>PRIS EN CHARGE JUSQU’EN :</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="924"/>
        <source>Show this dialog at start up</source>
        <translation>Afficher cette fenêtre au démarrage</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="78"/>
        <source>User demo, password:</source>
        <translation>Utilisateur demo, mot de passe :</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="78"/>
        <source>Superuser root, password:</source>
        <translation>Superutilisateur root, mot de passe :</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="178"/>
        <location filename="mainwindow.cpp" line="194"/>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="255"/>
        <source>About MX Welcome</source>
        <translation>À propos de MX Centre d’accueil</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="255"/>
        <source>Version: </source>
        <translation>Version : </translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="255"/>
        <source>Program for displaying a welcome screen in MX Linux</source>
        <translation>Programme affichant un écran d’accueil pour MX Linux</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="255"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="256"/>
        <source>License</source>
        <translation>Licence</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="257"/>
        <source>Changelog</source>
        <translation>Journal des modifications</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="258"/>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="274"/>
        <source>&amp;Close</source>
        <translation>&amp;Quitter</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="main.cpp" line="71"/>
        <source>You must run this program as normal user.</source>
        <translation>Vous devez exécuter cette application en tant qu’utilisateur normal.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="main.cpp" line="44"/>
        <source>This tool displays a welcome screen with two tabs.</source>
        <translation>Cet outil affiche un écran de bienvenue avec deux onglets.</translation>
    </message>
    <message>
        <location filename="main.cpp" line="47"/>
        <source>Start with About tab selected. The About tab provides basic information about the current MX Linux version, the user&apos;s hardware, and access to a full system report.</source>
        <translation>Commencer avec l’onglet « À propos » sélectionné. L’onglet « À propos » fournit des informations de base sur la version actuelle de MX Linux, le matériel de l’utilisateur et l’accès à un rapport complet du système.</translation>
    </message>
    <message>
        <location filename="main.cpp" line="50"/>
        <source>Run a test mode.</source>
        <translation>Exécuter en mode test.</translation>
    </message>
    <message>
        <location filename="main.cpp" line="71"/>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
</context>
</TS>

==> mx-welcome_25.11.02mx25.tar.xz: mx-welcome/translations/mx-welcome_fr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="fr">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="mainwindow.ui" line="14"/>
        <location filename="mainwindow.cpp" line="65"/>
        <location filename="mainwindow.cpp" line="255"/>
        <location filename="mainwindow.cpp" line="264"/>
        <source>MX Welcome</source>
        <translation>MX Centre d’accueil - MX Welcome</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="80"/>
        <source>Quit application</source>
        <translation>Quitter l’application</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="83"/>
        <source>Close</source>
        <translation>Quitter</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="90"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="112"/>
        <source>About this application</source>
        <translation>À propos de cette application</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="115"/>
        <source>About...</source>
        <translation>À propos…</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="122"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="203"/>
        <source>Welcome</source>
        <translation>Centre d’accueil - Welcome</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="484"/>
        <source>Install MX Linux</source>
        <translation>Installer MX Linux</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="510"/>
        <source>Tweak (Panel, etc...)</source>
        <translation>Ajustements (Tableau de bord, etc. …)</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="536"/>
        <source>Tools</source>
        <translation>Outils </translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="568"/>
        <source>Wiki</source>
        <translation>Wiki</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="600"/>
        <source>Users Manual</source>
        <translation>Manuel de l’utilisateur</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="626"/>
        <source>FAQ</source>
        <translation>FAQ</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="652"/>
        <source>Tour</source>
        <translation>Tour</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="674"/>
        <source>Popular Apps</source>
        <translation>Applications populaires</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="700"/>
        <source>Contribute</source>
        <translation>Contribuer</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="732"/>
        <source>Videos</source>
        <translation>Vidéos</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="764"/>
        <source>Forums</source>
        <translation>Forums</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="790"/>
        <source>About</source>
        <translation>À propos</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="798"/>
        <source>SHORT SYSTEM REPORT:</source>
        <translation>RAPPORT SUCCINCT DU SYSTÈME :</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="805"/>
        <source>DESKTOP</source>
        <translation>BUREAU</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="819"/>
        <source>Quick-System-Info Full Report</source>
        <translation>Quick-System-Info rapport complet</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="829"/>
        <source>Terms of Use</source>
        <translation>Conditions d’utilisation</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="846"/>
        <source>The name “MX Linux” is covered by Linux Foundation Sublicense No. 20140605-0483. We develop software that is covered by a free license that can be examined in the Wiki list. We also include software developed by others that is under a free license.</source>
        <translation>Le nom « MX Linux » est couvert par la sous-licence de la Fondation Linux n° 20140605-0483. Nous développons des logiciels qui sont couverts par une licence libre qui peut être examinée dans la liste Wiki. Nous incluons également des logiciels développés par d’autres qui sont sous une licence libre.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="856"/>
        <source>MX VERSION</source>
        <translation>VERSION MX</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="863"/>
        <source>DEBIAN VERSION:</source>
        <translation>VERSION DEBIAN :</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="870"/>
        <source>SUPPORTED UNTIL:</source>
        <translation>PRIS EN CHARGE JUSQU’EN :</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="924"/>
        <source>Show this dialog at start up</source>
        <translation>Afficher cette fenêtre au démarrage</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="78"/>
        <source>User demo, password:</source>
        <translation>Utilisateur demo, mot de passe :</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="78"/>
        <source>Superuser root, password:</source>
        <translation>Superutilisateur root, mot de passe :</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="178"/>
        <location filename="mainwindow.cpp" line="194"/>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="255"/>
        <source>About MX Welcome</source>
        <translation>À propos de MX Centre d’accueil</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="255"/>
        <source>Version: </source>
        <translation>Version : </translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="255"/>
        <source>Program for displaying a welcome screen in MX Linux</source>
        <translation>Programme affichant un écran d’accueil pour MX Linux</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="255"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="256"/>
        <source>License</source>
        <translation>Licence</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="257"/>
        <source>Changelog</source>
        <translation>Journal des modifications</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="258"/>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="274"/>
        <source>&amp;Close</source>
        <translation>&amp;Quitter</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="main.cpp" line="71"/>
        <source>You must run this program as normal user.</source>
        <translation>Vous devez exécuter cette application en tant qu’utilisateur normal.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="main.cpp" line="44"/>
        <source>This tool displays a welcome screen with two tabs.</source>
        <translation>Cet outil affiche un écran de bienvenue avec deux onglets.</translation>
    </message>
    <message>
        <location filename="main.cpp" line="47"/>
        <source>Start with About tab selected. The About tab provides basic information about the current MX Linux version, the user&apos;s hardware, and access to a full system report.</source>
        <translation>Commencer avec l’onglet « À propos » sélectionné. L’onglet « À propos » fournit des informations de base sur la version actuelle de MX Linux, le matériel de l’utilisateur et l’accès à un rapport complet du système.</translation>
    </message>
    <message>
        <location filename="main.cpp" line="50"/>
        <source>Run a test mode.</source>
        <translation>Exécuter en mode test.</translation>
    </message>
    <message>
        <location filename="main.cpp" line="71"/>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
</context>
</TS>
